OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Zu den Favoriten hinzugefügt",
    "Removed from favorites" : "Aus den Favoriten entfernt",
    "You added {file} to your favorites" : "Du hast {file} zu deinen Favoriten hinzugefügt",
    "You removed {file} from your favorites" : "Du hast {file} aus deinen Favoriten entfernt",
    "Favorites" : "Favoriten",
    "File changes" : "Dateiänderungen",
    "Created by {user}" : "Erstellt durch {user}",
    "Changed by {user}" : "Geändert durch {user}",
    "Deleted by {user}" : "Gelöscht durch {user}",
    "Restored by {user}" : "Wiederhergestellt durch {user}",
    "Renamed by {user}" : "Umbenannt durch {user}",
    "Moved by {user}" : "Verschoben durch {user}",
    "\"remote account\"" : "\"Entferntes Konto\"",
    "You created {file}" : "Du hast {file} erstellt",
    "You created an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} erstellt",
    "{user} created {file}" : "{user} hat {file} erstellt",
    "{user} created an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} erstellt",
    "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
    "You changed {file}" : "Du hast {file} geändert",
    "You changed an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} geändert",
    "{user} changed {file}" : "{user} hat {file} geändert",
    "{user} changed an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} geändert",
    "You deleted {file}" : "Du hast {file} gelöscht",
    "You deleted an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} gelöscht",
    "{user} deleted {file}" : "{user} hat {file} gelöscht",
    "{user} deleted an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} gelöscht",
    "You restored {file}" : "Du hast {file} wiederhergestellt",
    "{user} restored {file}" : "{user} hat {file} wiederhergestellt",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Du hast {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} (hidden) to {newfile}" : "Du hast {oldfile} (versteckt) in {newfile} umbenannt",
    "You renamed {oldfile} to {newfile} (hidden)" : "Du hast {oldfile} in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} to {newfile}" : "Du hast {oldfile} in {newfile} umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} hat {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} hat {oldfile} (versteckt) in {newfile} umbenannt",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} hat {oldfile} in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} to {newfile}" : "{user} hat {oldfile} in {newfile} umbenannt",
    "You moved {oldfile} to {newfile}" : "Du hast {oldfile} nach {newfile} verschoben",
    "{user} moved {oldfile} to {newfile}" : "{user} hat {oldfile} nach {newfile} verschoben",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde deinen <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
    "Files" : "Dateien",
    "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
    "Failed to authorize" : "Autorisierung fehlgeschlagen",
    "Invalid folder path" : "Ungültiger Order-Pfad",
    "Folder not found" : "Ordner nicht gefunden",
    "The file cannot be found" : "Die Datei kann nicht gefunden werden",
    "The destination path does not exist: %1$s" : "Der Zielpfad existiert nicht: %1$s",
    "You do not have permission to create a file at the specified location" : "Keine Berechtigung, eine Datei am angegebenen Speicherort zu erstellen",
    "The file could not be converted." : "Die Datei konnte nicht konvertiert werden.",
    "Could not get relative path to converted file" : "Relativer Pfad zur konvertierten Datei konnte nicht ermittelt werden",
    "Favorite files" : "Favorisierte Dateien",
    "No favorites" : "Keine Favoriten",
    "More favorites" : "Weitere Favoriten",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "Accept" : "Akzeptieren",
    "Reject" : "Ablehnen",
    "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
    "Ownership transfer denied" : "Besitzübertragung verweigert",
    "Your ownership transfer of {path} was denied by {user}." : "Die Besitzübertragung von {path} wurde von {user} abgelehnt.",
    "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
    "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
    "The ownership transfer of {path} from {user} failed." : "Die Übertragung von {path} ist fehlgeschlagen.",
    "Ownership transfer done" : "Besitzübertragung abgeschlossen",
    "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
    "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
    "in %s" : "in %s",
    "Transferred from %1$s on %2$s" : "Übertragen von %1$s auf %2$s",
    "Files compatibility" : "Dateikompatibilität",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
    "File Management" : "Dateiverwaltung",
    "Home" : "Home",
    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
    "Reload current directory" : "Aktuelles Verzeichnis neu laden",
    "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}\" wechseln",
    "Current directory path" : "Aktueller Verzeichnispfad",
    "Your have used your space quota and cannot upload files anymore" : "Dein Speicherplatzkontigent ist aufgebraucht, du kannst keine weiteren Dateien hochladen.",
    "You do not have permission to upload or create files here." : "Du hast nicht die Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
    "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
    "Favorite" : "Favorit",
    "Back" : "Zurück",
    "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
    "Toggle selection for folder \"{displayName}\"" : "Auswahl für den Ordner \"{displayName}\" umschalten",
    "File is loading" : "Datei wird geladen",
    "Folder is loading" : "Ordner wird geladen",
    "Filename" : "Dateiname",
    "Folder name" : "Ordnername",
    "This node is unavailable" : "Dieser Knoten ist nicht verfügbar.",
    "Another entry with the same name already exists." : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
    "Invalid filename." : "Ungültiger Dateiname.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
    "Rename file" : "Datei umbenennen",
    "Pending" : "Ausstehend",
    "Unknown date" : "Unbekanntes Datum",
    "Clear filter" : "Filter zurücksetzen",
    "Modified" : "Geändert",
    "Type" : "Typ",
    "Active filters" : "Aktive Filter",
    "Remove filter" : "Filter entfernen",
    "Total rows summary" : "Zusammenfassung aller Zeilen",
    "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
    "Name" : "Name",
    "Size" : "Größe",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
    "Actions" : "Aktionen",
    "(selected)" : "(ausgewählt)",
    "List of files and folders." : "Liste der Dateien und Ordner",
    "You have used your space quota and cannot upload files anymore." : "Dein Speicherplatzkontigent ist aufgebraucht, Du kannst keine weiteren Dateien hochladen.",
    "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste wird aus Performance-Gründen nicht vollständig angezeigt. Die Dateien werden angezeigt, wenn du durch die Liste navigierst.",
    "File not found" : "Datei nicht gefunden",
    "{count} selected" : "{count} ausgewählt",
    "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
    "{used} of {quota} used" : "{used} von {quota} verwendet",
    "{relative}% used" : "{relative}% verwendet",
    "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
    "Your storage is full, files can not be updated or synced anymore!" : "Der Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage information" : "Speicherinformation",
    "Storage quota" : "Speicherkontingent",
    "New folder" : "Neuer Ordner",
    "Create new folder" : "Neuen Ordner erstellen",
    "This name is already in use." : "Dieser Name wird bereits verwendet.",
    "Create" : "Erstellen",
    "Fill template fields" : "Vorlagenfelder ausfüllen",
    "Submitting fields …" : "Felder werden übermittelt …",
    "Submit" : "Übermitteln",
    "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Transfer" : "Übertragen",
    "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
    "Invalid path selected" : "Ungültiger Dateipfad ausgewählt",
    "Unknown error" : "Unbekannter Fehler",
    "Ownership transfer request sent" : "Anforderung für die Übertragung des Besitzes gesendet",
    "Cannot transfer ownership of a file or folder you do not own" : "Der Besitz an einer Datei oder einem Ordner, der dir nicht gehört, kann nicht übertragen werden",
    "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
    "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Change" : "Ändern",
    "New owner" : "Neuer Besitzer",
    "Keep {old}" : "{old} behalten",
    "Keep without extension" : "Ohne Erweiterung behalten",
    "Use {new}" : "{new} verwenden",
    "Remove extension" : "Dateierweiterung entfernen",
    "Change file extension" : "Dateierweiterungen ändern",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Ändern der Dateierweiterung von \"{old}\" zu \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Entfernen der Dateierweiterung \"{old}\" kann dazu führen, dass die Datei unlesbar wird.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Hinzufügen der Dateierweiterung \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
    "Do not show this dialog again." : "Diesen Dialog nicht mehr anzeigen.",
    "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
    "Choose {file}" : "{file} auswählen",
    "Share" : "Teilen",
    "Shared by link" : "Über einen Link geteilt",
    "Shared" : "Geteilt",
    "Switch to list view" : "Zur Listenansicht wechseln",
    "Switch to grid view" : "Zur Rasteransicht wechseln",
    "The file could not be found" : "Die Datei konnte nicht gefunden werden",
    "Upload was cancelled by user" : "Das Hochladen wurde vom Benutzer abgebrochen.",
    "Not enough free space" : "Nicht genügend freier Speicherplatz",
    "Operation is blocked by access control" : "Vorgang wird durch die Zugangskontrolle blockiert",
    "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
    "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
    "Unknown error during upload" : "unbekannte Fehler während des Hochladens",
    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
    "Loading current folder" : "Lade aktuellen Ordner",
    "Retry" : "Wiederholen",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere sie mit deinen Geräten!",
    "Go back" : "Zurückgehen",
    "Filter file names …" : "Dateinamen filtern …",
    "Views" : "Ansichten",
    "Files settings" : "Dateien-Einstellungen",
    "Your files" : "Deine Dateien",
    "Open in files" : "In Dateien öffnen",
    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Du hast keine Berechtigung, um sie anzuzeigen. Bitte den Absender, die Datei zu teilen.",
    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
    "Sort favorites first" : "Favoriten zuerst sortieren",
    "Sort folders before files" : "Ordner vor Dateien sortieren",
    "Show hidden files" : "Versteckte Dateien anzeigen",
    "Crop image previews" : "Bildvorschauen zuschneiden",
    "Enable the grid view" : "Rasteransicht aktivieren",
    "Enable folder tree" : "Baumstruktur für Ordner aktivieren",
    "Additional settings" : "Zusätzliche Einstellungen",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "In die Zwischenablage kopieren",
    "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn du 2FA aktiviert hast, musst du ein neues App-Passwort erstellen und verwenden, indem du hier klickst.",
    "Warnings" : "Warnungen",
    "Prevent warning dialogs from open or reenable them." : "Öffnen von Warndialogen verhindern oder diese erneut aktivieren.",
    "Show a warning dialog when changing a file extension." : "Beim Ändern einer Dateierweiterung einen Warndialog anzeigen.",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "Speed up your Files experience with these quick shortcuts." : "Mit diesen Schnellzugriffen schneller mit Dateien arbeiten.",
    "Open the actions menu for a file" : "Aktionsmenü für eine Datei öffnen",
    "Rename a file" : "Eine Datei umbenennen",
    "Delete a file" : "Eine Datei löschen",
    "Favorite or remove a file from favorites" : "Datei favorisieren oder aus den Favoriten entfernen",
    "Manage tags for a file" : "Schlagworte für eine Datei verwalten",
    "Selection" : "Auswahl",
    "Select all files" : "Alle Dateien auswählen",
    "Deselect all files" : "Auswahl aller Dateien aufheben",
    "Select or deselect a file" : "Auswählen oder Auswahl einer Datei aufheben",
    "Select a range of files" : "Einen Bereich von Dateien auswählen",
    "Navigation" : "Navigation",
    "Navigate to the parent folder" : "In den übergeordneten Ordner navigieren",
    "Navigate to the file above" : "Zur obigen Datei navigieren",
    "Navigate to the file below" : "Zur unteren Datei navigieren",
    "Navigate to the file on the left (in grid mode)" : "Zur Datei links navigieren (In der Kachelansicht)",
    "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (In der Kachelansicht)",
    "View" : "Ansehen",
    "Toggle the grid view" : "Kachelansicht umschalten",
    "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen",
    "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
    "You" : "Du",
    "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
    "Owner" : "Besitzer",
    "Remove from favorites" : "Aus Favoriten entfernen",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "Tags" : "Schlagworte",
    "Blank" : "Leer",
    "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
    "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
    "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
    "Creating file" : "Datei erstellen",
    "Save as {displayName}" : "Speichern als {displayName}",
    "Save as …" : "Speichern als …",
    "Converting files …" : "Dateien werden konvertiert …",
    "Failed to convert files: {message}" : "Fehler beim Konvertieren der Dateien: {message}",
    "All files failed to be converted" : "Alle Dateien konnten nicht konvertiert werden",
    "One file could not be converted: {message}" : "Eine Datei konnte nicht konvertiert werden: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Eine Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Eine Datei erfolgreich konvertiert","%n Dateien erfolgreich konvertiert"],
    "Files successfully converted" : "Dateien erfolgreich konvertiert",
    "Failed to convert files" : "Dateien konnten nicht konvertiert werden",
    "Converting file …" : "Datei wird konvertiert …",
    "File successfully converted" : "Datei erfolgreich konvertiert",
    "Failed to convert file: {message}" : "Fehler beim Konvertieren der Datei: {message}",
    "Failed to convert file" : "Datei konnte nicht konvertiert werden",
    "Deletion cancelled" : "Löschen abgebrochen",
    "Leave this share" : "Diese Freigabe verlassen",
    "Leave these shares" : "Diese Freigaben verlassen",
    "Disconnect storage" : "Speicher trennen",
    "Disconnect storages" : "Speicher trennen",
    "Delete permanently" : "Endgültig löschen",
    "Delete and unshare" : "Löschen und nicht mehr teilen",
    "Delete file" : "Datei löschen",
    "Delete files" : "Dateien löschen",
    "Delete folder" : "Ordner löschen",
    "Delete folders" : "Ordner löschen",
    "Delete" : "Löschen",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sie sind dabei, {count} Element endgültig zu löschen","Du bist dabei, {count} Elemente endgültig zu löschen."],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Du bist dabei, {count} Elemente zu löschen."],
    "Confirm deletion" : "Löschen bestätigen",
    "Cancel" : "Abbrechen",
    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden.",
    "(copy)" : "(Kopie)",
    "(copy %n)" : "(Kopie %n)",
    "Move cancelled" : "Verschieben abgebrochen",
    "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
    "The files are locked" : "Die Dateien sind gesperrt",
    "The file does not exist anymore" : "Die Datei existiert nicht mehr",
    "Choose destination" : "Ziel wählen",
    "Copy to {target}" : "Nach {target} kopieren",
    "Copy" : "Kopieren",
    "Move to {target}" : "Nach {target} verschieben",
    "Move" : "Verschieben",
    "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
    "Move or copy" : "Verschieben oder kopieren",
    "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
    "Cancelled move or copy operation" : "Verschieben oder Kopieren abgebrochen",
    "Open folder {displayName}" : "Ordner {displayName} öffnen",
    "Open in Files" : "In \"Dateien\" öffnen",
    "Open file locally" : "Datei lokal öffnen",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf deinem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfe, ob du die Desktop-App installiert hast.",
    "Retry and close" : "Erneut versuchen und schließen",
    "Open online" : "Online öffnen",
    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
    "Open locally" : "Lokal öffnen",
    "Rename" : "Umbenennen",
    "Open details" : "Details öffnen",
    "View in folder" : "In Ordner anzeigen",
    "Today" : "Heute",
    "Last 7 days" : "Die letzten 7 Tage",
    "Last 30 days" : "Die letzten 30 Tage",
    "This year ({year})" : "Dieses Jahr ({year})",
    "Last year ({year})" : "Letztes Jahr ({year})",
    "Documents" : "Dokumente",
    "Spreadsheets" : "Tabellenkalkulationen",
    "Presentations" : "Präsentationen",
    "PDFs" : "PDFs",
    "Folders" : "Ordner",
    "Audio" : "Audio",
    "Photos and images" : "Fotos und Bilder",
    "Videos" : "Videos",
    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
    "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
    "Unable to initialize the templates directory" : "Der Vorlagenordner konnte nicht initialisiert werden",
    "Create templates folder" : "Vorlagenordner erstellen",
    "Templates" : "Vorlagen",
    "New template folder" : "Neuer Vorlagenordner",
    "In folder" : "Im Ordner",
    "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
    "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Dein Browser unterstützt die Dateisystem-API nicht. Verzeichnisse werden nicht hochgeladen.",
    "No files to upload" : "Keine Dateien zum Hochladen",
    "Unable to create the directory {directory}" : "Der Ordner {directory} konnte nicht erstellt werden",
    "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden",
    "Files uploaded successfully" : "Dateien hochgeladen",
    "No files to process" : "Keine Dateien zum Verarbeiten",
    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden.",
    "Files copied successfully" : "Dateien kopiert",
    "Files moved successfully" : "Dateien verschoben",
    "Conflicts resolution skipped" : "Konfliktlösung übersprungen",
    "Upload cancelled" : "Hochladen abgebrochen",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder die Administration kontaktieren.",
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Unexpected error: {error}" : "Unerwarteter Fehler: {error}",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
    "_(%n hidden)_::_ (%n hidden)_" : ["(%n versteckt)","(%n versteckt)"],
    "Filename must not be empty." : "Dateiname darf nicht leer sein.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ist innerhalb eines Dateinamens nicht zulässig.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ist ein reservierter Name und für Dateinamen nicht zulässig.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ist kein zulässiger Dateityp.",
    "Filenames must not end with \"{extension}\"." : "Dateinamen dürfen nicht mit \"{extension}\" enden.",
    "List of favorite files and folders." : "Liste der favorisierten Ordner und Dateien.",
    "No favorites yet" : "Noch keine Favoriten vorhanden",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
    "All files" : "Alle Dateien",
    "List of your files and folders." : "Liste deiner Dateien und Ordner",
    "All folders" : "Alle Ordner",
    "Personal files" : "Persönliche Dateien",
    "List of your files and folders that are not shared." : "Liste deiner Dateien und Ordner, die nicht geteilt wurden.",
    "No personal files found" : "Keine persönlichen Dateien gefunden",
    "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
    "Recent" : "Neueste",
    "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner",
    "No recently modified files" : "Keine kürzlich geänderten Dateien",
    "Files and folders you recently modified will show up here." : "Die von dir kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "File could not be found" : "Datei konnte nicht gefunden werden",
    "Download" : "Herunterladen",
    "Show list view" : "Listenansicht anzeigen",
    "Show grid view" : "Rasteransicht anzeigen",
    "Close" : "Schließen",
    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
    "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
    "Upload cancelled." : "Hochladen abgebrochen.",
    "Processing files …" : "Dateien werden verarbeitet …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
    "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
    "File could not be uploaded" : "Datei konnte nicht hochgeladen werden.",
    "Uploading …" : "Lade hoch …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Lade hoch … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
    "Choose target folder" : "Zielordner wählen",
    "Set reminder" : "Erinnerung erstellen",
    "Edit locally" : "Lokal bearbeiten",
    "Open" : "Öffnen",
    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
    "Details" : "Details",
    "Please select tag(s) to add to the selection" : "Bitte das/die Schlagwort(e) auswählen, das/die zur Auswahl hinzugefügt werden soll(en)",
    "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
    "Select directory \"{dirName}\"" : "Verzeichnis \"{dirName}\" auswählen",
    "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
    "copy" : "Kopie",
    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
    "{newName} already exists" : "{newName} existiert bereits",
    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{targetName}\" wird bereits im Ordner \"{dir}\" benutzt. Bitte einen anderen Namen verwenden.",
    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert.",
    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden, da dieser bereits existiert",
    "Could not fetch file details \"{file}\"" : "Details zu \"{file}\" konnten nicht ermittelt werden",
    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Gib mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen.",
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "{dirs} and {files}" : "{dirs} und {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
    "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
    "New" : "Neu",
    "New file/folder menu" : "Menü für neue Datei/Ordner",
    "Select file range" : "Dateibereich auswählen",
    "{used}%" : "{used}%",
    "{used} used" : "{used} verwendet",
    "\"{name}\" is an invalid file name." : "\"{name}\" ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ist kein erlaubter Dateityp",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppenordner \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externer Speicher \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppenordner \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externer Speicher \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
    "Path" : "Pfad",
    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
    "Favorited" : "Favorisiert",
    "Copy direct link (only works for people who have access to this file/folder)" : "Direktlink kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
    "Upload file" : "Datei hochladen",
    "Not favorited" : "Nicht favorisiert",
    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
    "You don't have permission to upload or create files here." : "Keine Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
    "Storage informations" : "Speicherinformationen",
    "Choose file" : "Datei auswählen",
    "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
    "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
    "Unable to change the favourite state of the file" : "Der Favorisiert-Status der Datei konnte nicht geändert werden",
    "Edit file locally" : "Datei lokal bearbeiten",
    "Edit online" : "Online bearbeiten",
    "Create new templates folder" : "Neuen Vorlagenordner erstellen",
    "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien",
    "Personal Files" : "Persönliche Dateien",
    "Text file" : "Textdatei",
    "New text file.txt" : "Neue Textdatei file.txt",
    "Favored" : "Favorisiert",
    "Favor" : "Favorisieren",
    "Not favored" : "Nicht favorisiert",
    "Submitting fields…" : "Felder werden übermittelt…",
    "Filter filenames…" : "Dateinamen filtern…",
    "{count} files could not be converted" : "{count} Dateien konnten nicht konvertiert werden",
    "{count} files successfully converted" : "{count} Dateien erfolgreich konvertiert"
},
"nplurals=2; plural=(n != 1);");
